# -*- coding: utf-8 -*-
"""
    django-gstorage
    ~~~~~~~~~~~~~~~

    A plug-and-play replacement for FileSystemStorage but
    using Google storage for persistence
"""

__version__ = '0.5.1'
__author__ = 'Fyndiq'
__license__ = 'MIT'
__copyright__ = 'Copyright 2016 Fyndiq AB'


default_app_config = 'gstorage.apps.GStorageConfig'
