# -*- coding: utf-8 -*-
"""
Collect all the constants required by the module in one place
"""

# Settings that are required for the library to perform correctly
REQUIRED_SETTINGS = (
    'GOOGLE_APPLICATION_CREDENTIALS',
    'GCLOUD_PROJECT_NAME',
    # default bucket that should be used to store assets
    'GCLOUD_DEFAULT_BUCKET_NAME',
)
